.. index file for emdfile documentation pages

``emdfile`` Documentation
=========================

``emdfile`` is a Python package that reads and writes `HDF5 <https://emdatasets.com/the-hdf5-file-format>`_ files
according to the `EMD 1.0 standard <https://emdatasets.com/format>`_.
It defines :ref:`read <read>` and :ref:`save <save>` functions and a small set of :doc:`classes <api/classes/index>` which together interface between EMD 1.0 and Python runtime objects.

:ref:`Installation <installation>`, :doc:`examples and usage <examples-usage>`, and the :doc:`API <api/index>` follow.
If you run into any issues, please let us know by `filing an issue <https://github.com/py4dstem/emdfile/issues>`_ on github.


.. _installation:

************
Installation
************

Install with

.. code-block::

    pip install emdfile

from the command line.



********
Contents
********

.. toctree::
   :maxdepth: 5
   :titlesonly:

   Examples and Usage <examples-usage.rst>
   API <api/index.rst>



